@@ -12,7 +12,8 @@ from vantage6.common.globals import DEFAULT_ENVIRONMENT, APPNAME
 from vantage6.common.configuration_manager import (
     ConfigurationManager
 )
-from vantage6.common import __version__
+from vantage6.common._version import __version__
+
 
 class AppContext(metaclass=Singleton):
 
@@ -73,9 +74,16 @@ class AppContext(metaclass=Singleton):
         # FIXME: this should probably be moved to the actual app
         module_name = __name__.split('.')[-1]
         self.log = logging.getLogger(module_name)
-        self.log.info("#" * 80)
-        self.log.info(f'#{APPNAME:^78}#')
-        self.log.info("#" * 80)
+        self.log.info("-" * 45)
+        # self.log.info(f'#{APPNAME:^78}#')
+        import pyfiglet
+        self.log.info(" Welcome to")
+        for line in pyfiglet.figlet_format(APPNAME, font='big').split('\n'):
+            self.log.info(line)
+        self.log.info(" --> Join us on Discord! https://discord.gg/rwRvwyK")
+        self.log.info(" --> Docs: https://docs.vantage6.ai")
+        self.log.info(" --> Blog: https://vantage6.ai")
+        self.log.info("-" * 45)
         self.log.info(f"Started application {APPNAME} with environment "
                       f"{self.environment}")
         self.log.info("Current working directory is '%s'" % os.getcwd())
@@ -101,7 +109,7 @@ class AppContext(metaclass=Singleton):
         self_.log = logging.getLogger(module_name)
         if self_.LOGGING_ENABLED:
             self_.setup_logging()
-        self_.log.debug("Test!")
+
         return self_
 
     @classmethod
@@ -123,7 +131,6 @@ class AppContext(metaclass=Singleton):
         config_manager = cls.INST_CONFIG_MANAGER.from_file(config_file)
         return bool(getattr(config_manager, environment))
 
-
     @staticmethod
     def type_data_folder(instance_type, system_folders):
         """Return OS specific data folder."""
